Documentation
¶
Overview ¶
Package arg provides mechanisms for defining and configuring command line arguments.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Argable ¶
type Argable interface {
int |
int8 |
int16 |
int32 |
int64 |
uint |
uint8 |
uint16 |
uint32 |
uint64 |
uintptr |
float32 |
float64 |
string |
*url.URL |
bool |
[]byte |
time.Time |
time.Duration |
net.IP
}
Argable is a type constraint that defines any type capable of being parsed as a command line arg.
Click to show internal directories.
Click to hide internal directories.